@@ -38,6 +38,12 @@ extern "C" {
 #  include <scsi/sg.h>
 #  include <scsi/scsi_ioctl.h>
 #endif
+#if defined (__CYGWIN__)
+#  include <windows.h>
+#  include <mmsystem.h>
+#  define CDROMEJECT CDROMEJECT /*Place holder until I figure out what this is*/
+#  define CDROMCLOSETRAY CDROMCLOSETRAY
+#endif
 
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -87,7 +93,7 @@ void cdromCtrl::setCdromdev( const string& _newVal){
 }
 /** Initialze the cdrom device. Disable sw eject */
 void cdromCtrl::init(){
-   
+    #if ! defined (__CYGWIN__)   
    if (verbose) cout << "CD-ROM init, using " << cdromdev << " as the CD-ROM device" << endl;
    /* do we have a CD-ROM device configured?  (REDUNDANT extra check) */
    if ( cdromdev != snull) {
@@ -103,6 +109,7 @@ void cdromCtrl::init(){
       }
    } else
       lineak_core_functions::msg("no CD-ROM device configured! (CD-ROM init)");
+   #endif
 }
 /** Close the cdrom tray. */
 void cdromCtrl::closeTray() {
@@ -114,9 +121,10 @@ void cdromCtrl::closeTray() {
       /* close the cdrom tray */
       lineak_core_functions::msg("... closing the CD-ROM tray");
       /** Close the cdrom tray */
+      #if ! defined (__CYGWIN__)
       if ( (ioctl(fp, CDROMCLOSETRAY)) == -1 )
          lineak_core_functions::error("... oops! failed to close the CD-ROM");
-
+      #endif
       //autoEject(fp, true);
    } else {
       lineak_core_functions::error(string("... oops! unable to open the CD-ROM device ") + cdromdev);
@@ -132,8 +140,10 @@ void cdromCtrl::openTray(){
          
       lineak_core_functions::msg("... ejecting the CD-ROM tray");
       /* eject the cdrom tray */
+      #if ! defined (__CYGWIN__)
       if ( (ioctl(fp, CDROMEJECT)) == -1 )
          lineak_core_functions::error("... oops! failed to eject the CD-ROM");
+      #endif
       //autoEject(fp,true);   
    } else {
         lineak_core_functions::error(string("... oops! unable to open the CD-ROM tray ") + cdromdev);
