@@ -30,6 +30,9 @@ using namespace std;
 #if defined (__FreeBSD__) || defined(__FreeBSD_kernel__)
 #  define DEFAULT_CDROM_DEVICE "/dev/cd0c"
 #endif
+#if defined (__CYGWIN__)
+#  define DEFAULT_CDROM_DEVICE "D:"
+#endif
 
 class cdromCtrl {
 public: 
