@@ -169,7 +169,7 @@ map<string,LKbd*>* DefLoader::getDefObj(vector<string> *results){
 	             the name format name1|name2 if indeed it is a toggleable key. */
 		 if (key.find('|') != string::npos) {
 		    key+='|';
-		    akey->setToggle(true);
+		    akey->setUsedAsToggle(true);
 		    string::size_type index;
 		    string tmp;
 	            //vector<string>names;
