@@ -27,6 +27,7 @@ LButton::LButton() : LObject(snull, PRESS, BUTTON) {
 LButton::~LButton() {}
 LButton::LButton(string name, unsigned int ibutton) : LObject(name, PRESS, BUTTON), button(ibutton) {
 }
+/**
 void LButton::serialize(ostream &out) {
    int com=0;
    if (name != snull) {
@@ -34,7 +35,7 @@ void LButton::serialize(ostream &out) {
       out << ":event_type=" << lineak_core_functions::getEventTypeString(event_type);
       out << ":type=" << lineak_core_functions::getTypeString(type);
       out << ":button=" << button;
-      if (!isToggle()) {
+      if (!isUsedAsToggle()) {
           out << ":toggle=false";
           for (map<unsigned int,LCommand>::iterator i = commands.begin(); i!= commands.end(); i++, com++) {
              out << ":command_entry=" << com;
@@ -61,8 +62,7 @@ void LButton::serialize(ostream &out) {
     error("Attempting to output an empty key!");
   }
 }
-
-
+*/
 void LButton::print(ostream&out)  {
    if (name != snull) {
    	out << "Object: " << name << endl;
@@ -71,8 +71,13 @@ void LButton::print(ostream&out)  {
 	out << "   button = " << button << endl;
 	//out << "   modifier = " << getModifierString() << endl;
 	//out << "   modifier numeric = " << modifier << endl;
-	if (!isToggle()) {
-		out << "   toggle = false" << endl;
+	if (isToggle())
+           out << "   is_toggle=true";
+        else
+           out << "   is_toggle=false";
+
+	if (!isUsedAsToggle()) {
+		out << "   used_toggle = false" << endl;
 	        for (map<unsigned int,LCommand>::iterator i = commands.begin(); i!= commands.end(); i++) {
 			out << "   modifier = " << LObject::getModifierString((i->first));
 			out << " and command = " << commands[(i->first)];
@@ -81,7 +86,7 @@ void LButton::print(ostream&out)  {
 		//out << "   and command = " << commands[name] << endl;
 	}
 	else {
-		out << "   toggle = true" << endl;
+		out << "   used_toggle = true" << endl;
 		for (map<string,LCommand>::const_iterator i = tog_commands.begin(); i != tog_commands.end(); i++) {
 			out << "    for togglename = " << i->first << " command = " << i->second << endl;
 		        out << "    and display name = " << tog_commandDisplayNames[i->first] << endl;
