@@ -35,8 +35,8 @@ LConfig::LConfig(const LConfig & rhs) : LConfigData() {
 		
                 directives.clear();
     		directives = rhs.directives;
-                vec.clear();
-                vec = rhs.vec;
+//                vec.clear();
+//                vec = rhs.vec;
 	}
 }
 LConfig & LConfig::operator=(const LConfig & rhs) {
@@ -45,8 +45,8 @@ LConfig & LConfig::operator=(const LConfig & rhs) {
 		
                 directives.clear();
     		directives = rhs.directives;
-                vec.clear();
-                vec = rhs.vec;
+//                vec.clear();
+//                vec = rhs.vec;
 	}
 	return *this;
 }
@@ -61,17 +61,24 @@ LConfig::~LConfig(){
 void LConfig::clear() {
   directives.clear();
   keycommtable.clear();
-  vec.clear();
 }
+/** Empty data for all key configurations */
+void LConfig::clearKeycomms() {
+  keycommtable.clear();
+}
+/** Get a directives value */
 string LConfig::getValue(string key) const {
 	return directives.getValue(key);
 }
+/** Set a directives value */
 void LConfig::setValue(string key, string value) {
 	directives.addValue(key,value);
 }
+/** Get a directives integer value */
 int LConfig::getIntValue(string key) const {
 	return directives.getIntValue(key);
 }
+/** Set a directives integer value */
 void LConfig::setValue(string key, int value) {
 	directives.addValue(key,value);
 }
@@ -114,6 +121,33 @@ void LConfig::addKeycomm(const string key, keycommand_info info) {
        }
     }
 }
+/** Remove an entry from a key. */
+void LConfig::removeKeycomm(const string key, keycommand_info info) {
+   map<const string, vector<keycommand_info> >::iterator it = keycommtable.begin();
+   it = keycommtable.find(key);
+   if ( it != keycommtable.end() ) {
+      // Find the entry.
+      vector<keycommand_info>::iterator mit = keycommtable[key].begin();
+      for (; mit != keycommtable[key].end(); mit++) {
+	     // Find a matching entry.
+	     if ( mit->config_name == info.config_name &&
+                  mit->parsed_name == info.parsed_name &&
+                  mit->modifiers == info.modifiers &&
+                  mit->command.getCommand() == info.command.getCommand() )	   
+		// Remove matching entry.
+                keycommtable[key].erase(mit);      
+      }
+   }
+}
+
+/** Remove a key */
+void LConfig::removeKey(const string key) {
+   if (haveKeycomm(key) && key != "")
+	   keycommtable.erase(key);
+}
+
+/** Return a vector of keycommand_info's that correspond to a key. 
+ *  We return by reference to allow updates. */
 vector<keycommand_info>& LConfig::getKeycomm(const string key) {
     map<const string, vector<keycommand_info> >::iterator it = keycommtable.begin();
     it = keycommtable.find(key);
@@ -125,11 +159,40 @@ vector<keycommand_info>& LConfig::getKeycomm(const string key) {
        return tv;
     }
 }
+vector<string> LConfig::getKeycommKeys() {
+     vector<string> ret;
+     map<const string, vector<keycommand_info> >::iterator it = keycommtable.begin();
+     for (; it!=keycommtable.end(); it++) {
+	     ret.push_back(it->first);
+     }
+     return ret;
+}
+
+bool LConfig::haveKeycomm(const string key) {
+     map<const string, vector<keycommand_info> >::iterator it = keycommtable.begin();
+     for (; it!=keycommtable.end(); it++) {
+	     if (it->first == key)
+		     return true;
+     }
+     return false;
+}
+
+/** Update all of the data for a key entry. */
+void LConfig::updateKeycommData(const string key, vector<keycommand_info> info) {
+    if ( keycommtable.find(key) != keycommtable.end() ) {
+	    keycommtable[key] = info;
+    }
+    else {
+	    //msg("Adding a new key through an update.");
+	    cout << "Adding key: " << key << " through an update" << endl;
+	    keycommtable[key] = info;
+    }
+}
 /** Is this an empty object? Our critieria of being empty is:
 	if both the conffilename and KeyboardType values are undefined or snull
 	if the command table is empty
 	*/
-bool LConfig::isEmpty(){
+const bool LConfig::isEmpty(){
 	msg("Checking some isSet's to see if they are empty.");
 	if ((!directives.isSet(_CD_KEYBOARD_TYPE) && !directives.isSet(_CD_USERCONFFILE)) || keycommtable.empty() )
 		return false;
@@ -153,9 +216,6 @@ void LConfig::print(ostream &out) {
 	        const vector<keycommand_info>& comms = (i->second);
 	        // For all of the structs in our map....	
 	        for (unsigned int j = 0; j < (i->second).size(); j++) {
-		     // If the display name is set, then print it out.
-		     //if ( comms[j].display_name != "" ) 
-			//     out << "[" << comms[j].display_name << "] ";
 		     // Print out the config file name
 		     out << comms[j].config_name << " = ";
 		     // Print out the command
