@@ -87,7 +87,18 @@ public:
 	void addKeycomm(const string key, keycommand_info info);
 	/** Get all of the configurations for a key */
 	vector<keycommand_info>& getKeycomm(const string key);
-
+	/** Remove the keycommand_info entry for a key. */
+	void removeKeycomm(const string key, keycommand_info info);
+	/** Remove all keycommand_info entries for a key, includig the key itself. */
+	void removeKey(const string key);
+        /** Update all of the data for a key entry. */
+	void updateKeycommData(const string key, vector<keycommand_info> info);
+	/** Get all keys for the Keycomm data */
+	vector<string> getKeycommKeys();
+	/** Do we have a configuration for a key? This returns whether or not
+	 *  we know about a key. */
+	bool haveKeycomm(const string key);
+	/** Get the name of the file that was parsed. */
 	inline string getFilename() const { return directives.getValue(_CD_USERCONFFILE); }
 
 	/** The setFilename method is used to set the name of the file that the LConfig
@@ -96,16 +107,26 @@ public:
 	void setFilename(string file);
 	/** Is the config object empty? For this to be a no, the directives object must
 	    contain values for the keys conffilename and KeyboardType */
-  	bool isEmpty();
+  	const bool isEmpty();
+	/** Overwrite the directives list */
 	inline void setDirectives(const ConfigDirectives& directivelist) { directives = directivelist; }
+	/** Get all keys in the ConfigDirectives list. */
+	vector<string> getDirectiveKeys() { return directives.getKeys(); }
+	vector<string> getDirectiveIntKeys() { return directives.getIntKeys(); }
+
 	/** print */
 	void print(ostream& out);
 	/** clear the config object */
 	void clear();
+	/** clear all key configuration information */
+	void clearKeycomms();
+
 private:
 	map<const string, vector<keycommand_info> > keycommtable;
 	ConfigDirectives directives;
-	vector<string> vec;
+	//vector<string> vec;
+	//tv exists just as an empty vector to return in the
+	//case that we have no value to return
 	vector<keycommand_info> tv;
 };
 
