@@ -60,6 +60,7 @@ extern "C" {
 #include <lineak/lockctrl.h>
 #include <lineak/lcommand.h>
 #include <lineak/msgpasser.h>
+#include <lineak/lobject.h>
 
 //#include "commandexec.h"
 
@@ -212,8 +213,9 @@ bool lineak_core_functions::parsedeffile(ConfigDirectives & prefs, LDef & def) {
 		usrdeffilename = homedir + LINEAKDIR;
 		usrdeffilename += DEFFILE;
    }
-   msg("Parsing: " + usrdeffilename);
+ 
    if (file_exists(usrdeffilename)) {
+      msg("Parsing: " + usrdeffilename);
       /* it exists, parse the contents */
       DefLoader defldr(usrdeffilename);
       udef = defldr.loadDef();
@@ -307,6 +309,7 @@ void lineak_core_functions::create_new_conf(ConfigDirectives & prefs, LDef & def
 	//string conffilename = prefs.getValue("conffilename");
 	//string cdromdev = prefs.getValue("CdromDevice");
 	//string mixdev = prefs.getValue("MixerDevice");
+	//LDef def = idef;
 	string homedir = getenv("HOME");
 	string kbtype = prefs.getValue(_CD_KEYBOARD_TYPE);
 
@@ -339,18 +342,33 @@ void lineak_core_functions::create_new_conf(ConfigDirectives & prefs, LDef & def
 // 		mixdev = DEFAULT_MIXER_DEVICE;
 // 	}
 
+	//cout << "create_new_conf: kbtype = " << kbtype << endl;
+        //cout << "printing prefs from create_new_conf" << endl;
+	//cout << prefs << endl;
+	//cout << "printing defs from create_new_conf" << endl;
+	//cout << def << endl;
+	
   	config = LConfig (prefs);
-  	//config.setFilename(prefs.getValue("conffilename"));
-  	LKbd kbd = def.getKeyboard(kbtype);
-  	const map< string, LObject*> & keytable = kbd.getObjects();
-        keycommand_info info;
+
+  	LKbd & kbd = def.getKeyboard(kbtype);
+	keycommand_info info;
+/**  	const map< string, LObject*> & keytable = kbd.getObjects(); */
         /** Setup the keyboard objects in the kbd object */
+	/**
   	for (map< string, LObject*>::const_iterator m = keytable.begin(); m != keytable.end(); m++) {
 	        info.config_name = m->first;
 		info.parsed_name = m->first;
 		info.modifiers = 0;
 		info.command = blank;
 		config.addKeycomm(m->first,info);
+        }*/
+	const vector<string> keylist = kbd.getNames();
+	for (vector<string>::const_iterator m = keylist.begin(); m != keylist.end(); m++) {
+                info.config_name = *m;
+                info.parsed_name = *m;
+                info.modifiers = 0;
+                info.command = blank;
+                config.addKeycomm(*m,info);
         }
 	Saver tmp(config.getFilename());
 
@@ -359,7 +377,15 @@ void lineak_core_functions::create_new_conf(ConfigDirectives & prefs, LDef & def
 	else {
 		cout << "\n*** Creating fresh configuration in " << config.getFilename() << "\n      for keyboard type: " << kbtype << endl;
 		cout << "NOTE: Now please edit the file and bind commands to the keys,\n      or use klineakconfig :)\n" << endl;
-  }
+        }
+	//cout << "create_new_conf: kbtype = " << kbtype << endl;
+        //cout << "printing prefs from create_new_conf second time" << endl;
+        //cout << prefs << endl;
+        //cout << "printing defs from create_new_conf second time" << endl;
+        //cout << def << endl;
+	//cout << "printing config from create_new_conf second time" << endl;
+	//cout << config << endl;
+
 }
 
 /* check if there's already a running lineakd for this $USER */
@@ -428,7 +454,7 @@ bool lineak_core_functions::is_running(string process) {
 string lineak_core_functions::getModifierString(unsigned int imod) {
 	// Print out the modifiers
 	string modifier_string[] = { "control", "shift", "alt", "mod2", "mod3", "mod4", "mod5"};
-	string str;
+	string str = "";
 		
 	if (imod & ControlMask)
 	{
@@ -492,6 +518,8 @@ EventType_t lineak_core_functions::getEventType(string event_type) {
 		return PRESS;
 	if (event_type == "RELEASE")
 		return RELEASE;
+	//Return an unknown
+	return UNKNOWN_EVENT;
 }
 string lineak_core_functions::getTypeString(KeyType_t type) {
 	switch (type) {
@@ -516,13 +544,18 @@ KeyType_t lineak_core_functions::getType(string type) {
 		return CODE;
         if (type == "BUTTON")
 		return BUTTON;
+	return UNKNOWN_KEY;
 }
 unsigned int lineak_core_functions::getModifierNumericValue(const string modstr) {
 	string modifiers = modstr;
 	unsigned int modifier = 0;
         string::size_type j = 0;
 	vector<string> mods;
-	
+
+        // If there is no modifier, return 0	
+	if ( modstr == "" || modstr == "default" )
+	   return 0;
+
 	// Add a '+' to the end so we have something to parse on in the 
 	// following while loop in the event that there is only one modifier.
 	if (modifiers[modifiers.size()-1] != '+') {
