@@ -61,11 +61,13 @@ void vfatal(const string message);
 
 string getModifierString(unsigned int imod);
 string getEventTypeString(EventType_t event_type);
+EventType_t getEventType(string event_type);
 string getTypeString(KeyType_t type);
+KeyType_t getType(string type);
 unsigned int getModifierNumericValue(const string modstr);
 
 void enable_IBMRA7993(void);
-void send_commands(string args);
+void send_commands(string command, string args);
 }
 
 #endif
