@@ -242,8 +242,8 @@ void LKbd::setCommands(LConfig &config) {
       /** If it's a togglable key, and 
           there are no entries for this key in the key1|key2 form, 
           we are using it as a toggle. */
-      if ((m->second)->isToggle() && vtmp.empty()) {
-      
+      if ((m->second)->isUsedAsToggle() && vtmp.empty()) {
+         vmsg("Processing toggle"); 
          /** If we are using different commands for each toggleable key part */
 	 vector<string> names = obj->getToggleNames();
 	 for (vector<string>::const_iterator i = names.begin(); i != names.end(); i++) {
@@ -252,7 +252,10 @@ void LKbd::setCommands(LConfig &config) {
 	    for (string::size_type i = 0; i < vtmp.size(); i++) {
 	      // Get the keycommand_info struct w/ the appropriate info.
 	      tmp = vtmp[i];
-	      obj->addModifier(0);
+	      // We no longer have to add a modifier to a toggleable key.
+	      // The rest of the code (Xmgr and lineakd-main.cpp understand how to
+	      // process toggleable keys w/o resorting to modifiers. 
+	      //obj->addModifier(0);
 	      obj->setCommand(tmp.command, tmp.parsed_name); // may need to be config_name
 	      obj->setToggleCommandDisplayName(tmp.display_name, tmp.parsed_name);
 	    }
@@ -262,10 +265,12 @@ void LKbd::setCommands(LConfig &config) {
 	 /** If we are treating a toggleable key as a normal key, i.e. one command 
 	     for the whole thing, such as play|pause = command in the config file. 
 	     Turn it's toggle status off. */
-         if ((m->second)->isToggle()) {
-            (m->second)->setToggle(false);
+         if ((m->second)->isUsedAsToggle()) {
+	    vmsg("Disabling toggleability on this key");
+            (m->second)->setUsedAsToggle(false);
          }
 	 if (!vtmp.empty()) {
+            vmsg("Ignoring toggle status.");
 	    /** Get the vector containing all information on keys with this name. */
 	    //vtmp = config.getKeycomm(*i);
 	    for (vector<keycommand_info>::size_type i = 0; i < vtmp.size(); i++) {
@@ -338,7 +343,7 @@ int LKbd::getNumObjectOfType(KeyType_t type) {
    return num;
 }
 /** Is the keyboard empty? */
-bool LKbd::isEmpty() {
+const bool LKbd::isEmpty() {
 	// An empty keyboard is one that has no name. The rest can be empty data,
 	// but we at least need a name.
 	if (name == snull)
@@ -356,8 +361,16 @@ void LKbd::print(ostream &out) {
            out << "     " <<  "RAWCOMMAND[" << i->first << "] = " << i->second << endl;
 	}
      	out << "     " << "[KEYS]" << endl;
-     	for (map< string, LObject*>::iterator i = table.begin(); i != table.end(); i++) {
+     	for (map<string, LObject*>::iterator i = table.begin(); i != table.end(); i++) {
+  //         cout << "look for the key types." << endl;
+//	   cout << "outputting the lobject." << endl;
+//	   if (i->second == NULL)
+//	      cout << "LObject data for the keys is null!" << endl;
+//	   else
+//	      cout << *(i->second) << endl;
+
 	   if ( i->second->getType() == CODE || i->second->getType() == SYM ) {
+//		   cout << "Looping over keys" << endl;
 	      LKey * key = static_cast<LKey *>(i->second);
 	      //cout << "Examining key..." << endl;
 	      //cout << *key << endl;
