@@ -81,7 +81,7 @@ class LKbd: public LConfigData
    int getNumObjectOfType(KeyType_t type);
 
    /** Is the lkbd object empty? */
-   bool isEmpty ();
+   const bool isEmpty ();
    /** Print */
    void print (ostream & out);
    /** Clear the object */
