@@ -319,17 +319,21 @@ void PluginManager::unloadPlugin(const string& plugin) {
                 dlclose(handle);
         }
 	msg("PluginManager: unloading plugin " + plugin);
-	plugin_map.erase(plugin);
+	//plugin_map.erase(plugin);
         vmsg("UnloadPlugin: exit");
 }
 /** Unloads all loaded plugins. */
 void PluginManager::unloadAllPlugins(){
         string name = "";
    	map<string,plugin_info>::iterator it = plugin_map.begin();
+	int n = plugin_map.size();
+	if (verbose) cout << "Plugins to unload: " << n << endl;
         msg("PluginManager is unloading plugins");
-	for (;it != plugin_map.end(); it++) {
+	//for (int i=0 ;it != plugin_map.end(); it++) {
+	for (unsigned int i=0 ;i < plugin_map.size(); i++) {
                 if (very_verbose) cout << "Calling unload for plugin: " << it->first << endl;
 		unloadPlugin(it->first);
+		it++;
 	}
 	vmsg("PluginManager finished unloading plugins");
         // Remove all plugin entries in the map.
@@ -588,8 +592,10 @@ bool PluginManager::defineDirectivesList(const string& plugin) {
 					msg("Adding directive: "+key);
                                         (plugin_map[plugin].directives).addValue(key, def);
 					// If the directive has not been defined by any other plugin...
-					if (!directivelist.isSet(key))
+					if (!directivelist.isSet(key)) {
 						directivelist.addValue(key, def);
+					}
+					msg("Finished adding directive: "+key);
        		                }
 				plugin_map[plugin].directives_defined = true;
 				return true;
@@ -668,6 +674,7 @@ exec_t PluginManager::exec(LObject* imyKey, XEvent xev) {
                 msg( "Plugin: " + string(it->first) + " to execute macro " + command.getMacroType());
                 exec = (it->second).exec;
 		if (exec != NULL) {
+			//cout << "Calling exec\n" << endl;
                         return (exec);
                         //cout << " Calling exec(imyKey)" << endl;
 			//exec(imyKey);
