@@ -339,8 +339,20 @@ void Xmgr::grabKey (LKey* key)
   if (verbose)
      cout << "grabKey for " << key->getName() << endl;
 
+  vector<unsigned int> mods;
+  
   /** Experimental */
-  vector<unsigned int> mods = key->getModifiers();
+  /** If the key is a toggleable key, it will not have any modifiers.
+   *  In this case we need to grab the default key code, so we need
+   *  mods[0] to be 0.
+   *  */
+  if (key->isUsedAsToggle()) {
+     mods.push_back(0);
+     mods.push_back(0);
+  }
+  else  
+     mods = key->getModifiers();
+
   for (vector<unsigned int>::size_type i=0; i < mods.size(); i++) {
      if (very_verbose) cout << "mods[" << i << "] = " << mods[i] << endl;
      modifier = mods[i];
