@@ -76,6 +76,7 @@ extern LDef myDef;
 extern Xmgr *X;
 extern CmdPrefs cmdprefs;
 extern bool verbose;
+extern bool very_verbose;
 extern bool global_enable;
 extern PluginManager *plugins;
 extern displayCtrl *myDisplay;
@@ -167,7 +168,7 @@ void lineakd_core_functions::showusage(int argc, char *argv[]) {
 	cout << "    -s,           Set the offset for the shadow behind displayed text.\n";
 #endif
   	cout << "\nNOTE: if '-f', '-e', '-d', or '-m' parameters are used in conjunction with '-c', please\n      make sure you specify those BEFORE '-c' !\n";
-  cout << endl;
+        cout << endl;
 }
 
 /* these functions provide for a somewhat cleaner exit */
@@ -191,8 +192,8 @@ void lineakd_core_functions::signalchild(int sig_num) {
   /*   may get merged. Handle this case correctly. */
   while ((child = waitpid(-1, NULL, WNOHANG)) > 0)
     {
-      if (verbose)
-        cout << "Catch CHLD signal -> pid " << child << " terminated" << endl;
+      if (very_verbose)
+        cout << "Catch CHLD signal -> pid " << child << " terminated with signal: " << sig_num << endl;
     }
 
 }
@@ -205,13 +206,13 @@ void lineakd_core_functions::signalexit(int sig_num) {
 	   cout.flush();
 	   // let all of the other threads continue so that only one sends the EXIT signal.
 	   sem_post(&exit_sem);
-	   if (verbose) cout << "Semaphore posted\n";
-  	   if (verbose) cout << "Recieved signal " << sig_num << endl;
-	   if (verbose) cout << "Sending of EXIT message handled by thread: " << pid << endl;
+	   if (very_verbose) cout << "Semaphore posted\n";
+  	   if (very_verbose) cout << "Recieved signal " << sig_num << endl;
+	   if (very_verbose) cout << "Sending of EXIT message handled by thread: " << pid << endl;
 	   cout.flush();
   	   msgPasser myMsg;
   	   if (!myMsg.start()) error("signalexit(): Cannot establish message queue to send an exit message.!");
-	   if (verbose) cout << "Sending EXIT message!" << endl;
+	   if (very_verbose) cout << "Sending EXIT message!" << endl;
   	   myMsg.sendMessage(msgPasser::EXIT,"exit");
 	   signaldone = false;
 	   sleep(1);
@@ -221,11 +222,15 @@ void lineakd_core_functions::signalexit(int sig_num) {
 	if (pid == watchpid)
 	  watch_messages();
 
-	if (verbose) cout << "pid: " << pid << " exiting signalexit()\n";
+	if (very_verbose) cout << "pid: " << pid << " exiting signalexit()\n";
 }
 void lineakd_core_functions::signalrestart(int sig_num) {
 	msgPasser myMsg;
-	if (!myMsg.start()) error("signalrestart(): Cannot establish message queue to send a HUP message.!");
+        stringstream ss;
+        ss << "signalrestart(";
+        ss << sig_num << "): Cannot establish message queue to send a HUP message.!";
+        string e = ss.str();
+	if (!myMsg.start()) error(e);
 	myMsg.sendMessage(msgPasser::HUP,"hup");
 }
 /* this is our "clean-up-that-mess" signal handler ;-) */
@@ -237,12 +242,12 @@ void lineakd_core_functions::do_exit() {
   cout.flush();
   if (verbose) cout << endl;
   if (verbose) cout << endl;
-  if (verbose) cout << "**** do_exit() initiated **** \n";
+  if (very_verbose) cout << "**** do_exit() initiated **** \n";
   cout.flush();
   /** Cancel the message thread */
 //  pthread_cancel(m_thread);
 //  cout << "pthread_cancelled\n";
-  if (verbose) cout << "**** sem_wait **** " << getpid() << endl;
+  if (very_verbose) cout << "**** sem_wait **** " << getpid() << endl;
   cout.flush();
   /** This is a section that we only want called once. */
   /* Put a semaphore here so that we can set doneexit atomically. */
@@ -398,7 +403,9 @@ void lineakd_core_functions::restart() {
 		plugins->initializePlugins(myKbd, myConfig,plugins);
 
   		msg("*** Restarting On Screen Display...");
-  		myDisplay->init(myConfig);
+		myDisplay = plugins->getDisplay(myConfig);
+  		//myDisplay->init(myConfig);
+		msg("*** InitializePluginsDisplay...");
                 plugins->initializePluginsDisplay(*myDisplay);
 
     	donehup=false;
@@ -417,7 +424,7 @@ void lineakd_core_functions::watch_messages() {
   // Initialise the semaphores here
   res = sem_init(&x_sem, 0,1);
   mainpid = getpid();
-  if (verbose) cout << "Main thread is: " << mainpid << endl;
+  if (very_verbose) cout << "Main thread is: " << mainpid << endl;
   if (sem_init(&exit_sem,0,1) != 0)
      perror("exit_sem: Semaphore initialization failed");
   if (sem_init(&doexit_sem,0,1) != 0)
@@ -456,10 +463,9 @@ void *lineakd_core_functions::handle_messages(void *arg) {
 		cleanexit(false);
 	}
 		
-	//bool verbose = cmdprefs.getVerbose();
         cout.flush();
 	watchpid = getpid();
-	if (verbose) cout << "**** Message handler thread is: " << watchpid << endl;
+	if (very_verbose) cout << "**** Message handler thread is: " << watchpid << endl;
         int res = pthread_setcancelstate(PTHREAD_CANCEL_ENABLE,NULL);
 	if (res != 0) {
 		perror("Thread cancel state failed");
@@ -473,7 +479,7 @@ void *lineakd_core_functions::handle_messages(void *arg) {
 	}
 
 	while (true) {
-//	        cout << "Waiting for message\n";
+  	        //lineak_core_functions::msg("Waiting for message");
      	        msg = myMsg.getMessage();
                 if (msg.msg_type == msgPasser::EXIT) {
 			lineak_core_functions::msg("Exit message");
@@ -494,71 +500,92 @@ void *lineakd_core_functions::handle_messages(void *arg) {
 			lineak_core_functions::msg("Enable message");
                         global_enable = true;
                 }
+		// parse the possible command types.
+		// Some of these don't work, and will not until all of the objects can be serialized
+		// and transmitted over IPC.
 		if (msg.msg_type == msgPasser::COMMAND) {
-		        LObject *key;
-			string *scomm;
-			char * ccomm;
-			LCommand *lcomm;
+		        //LObject *key;
+			//string *scomm;
+			//char * ccomm;
+			//LCommand *lcomm;
 			lineak_core_functions::msg("Run external command");
 			switch (msg.directive.data_type) {
+				// empty command
 				case NODATA:
 					lineak_core_functions::msg("Empty command");
 					break;
+				// command passed as an LObject
 				case LOBJECT:
 					lineak_core_functions::msg("LObject command");
-					key = static_cast<LObject*>(msg.directive.data);
-					lineak_core_functions::msg((key->getCommand()).getCommand());
-					delete(key);
+					//key = static_cast<LObject*>(msg.directive.data);
+					//lineak_core_functions::msg((key->getCommand()).getCommand());
+					//delete(key);
 					break;
+				case LOBJECT_BYNAME:
+					lineak_core_functions::msg("LObject command");
+                                        
+					//scomm = static_cast<string*>(msg.directive.data);
+					//lineak_core_functions::msg("LObject name: " + *scomm);
+                                        //delete(scomm);
+                                        break;
+				// command passed as a string
 				case STRING_COMMAND:
 					lineak_core_functions::msg("String command");
-					scomm = static_cast<string*>(msg.directive.data);
-					lineak_core_functions::msg(*scomm);
-					delete(scomm);
+					//scomm = static_cast<string*>(msg.directive.data);
+					//lineak_core_functions::msg(*scomm);
+					cout << msg.directive.args << endl;
+					//delete(scomm);
 					break;
 				case CHAR_COMMAND:
 					lineak_core_functions::msg("char command");
-					ccomm = static_cast<char*>(msg.directive.data);
+					//ccomm = static_cast<char*>(msg.directive.data);
 					//lineak_core_functions::msg(*((const char*)ccomm));
-					if (verbose) cout << ccomm << endl;
-					delete(ccomm);
+					//if (verbose) cout << ccomm << endl;
+					//delete(ccomm);
 					break;
 				case LCOMMAND:
 					lineak_core_functions::msg("LCommand command");
-					lcomm = static_cast<LCommand*>(msg.directive.data);
-					lineak_core_functions::msg(lcomm->getCommand());
-					delete(lcomm);
+					//lcomm = static_cast<LCommand*>(msg.directive.data);
+					//lineak_core_functions::msg(lcomm->getCommand());
+					//delete(lcomm);
 					break;
 				default:
 					lineak_core_functions::msg("Unknown data_type");
 			}
 		}
+		/* This concept will work when we can [un]serialize these classes and send over IPC. */
 		if (msg.msg_type == msgPasser::GETDATA) {
 		        lineak_core_functions::msg("Return data");
+                        cout << "GETDATA" << endl;
 			switch (msg.directive.data_type) {
 				case NODATA:
 					break;
-				case LOBJECT:
+				case LOBJECT_BYNAME:
 					{
 					// Get the name of the object requested.
 					string name = msg.directive.args;
+                                        string data, d;
+                                        stringstream ss (data, stringstream::in | stringstream::out);
 					LObject *obj = myKbd.getObject(name);
-					eak_msg retmsg;
+                                        ss << *obj;
+                                        d = ss.str();
+					eak_data retmsg;
 					retmsg.msg_type = msgPasser::SENDDATA;
 					retmsg.directive.data_type = LOBJECT;
-					retmsg.directive.data = static_cast<void*>(obj);
-					strcpy(retmsg.directive.args, name.c_str());
+					strcpy(retmsg.directive.args, d.c_str());
+           cout << "Sending a key back." << endl;
+           cout << "Key string: " << d << endl;
 					myMsg.sendMessage(retmsg); }
 					break; 
 				case LCONFIG: 
 					{
 					// Get the name of the object requested.
 					//string name = msg.directive.args;
-					LConfig *obj = &myConfig;
+					//LConfig *obj = &myConfig;
 					eak_msg retmsg;
 					retmsg.msg_type = msgPasser::SENDDATA;
 					retmsg.directive.data_type = LCONFIG;
-					retmsg.directive.data = static_cast<void*>(obj);
+					//retmsg.directive.data = static_cast<void*>(obj);
 					//strcpy(retmsg.directive.args, name.c_str());
 					myMsg.sendMessage(retmsg); }
 					break;
@@ -566,11 +593,11 @@ void *lineakd_core_functions::handle_messages(void *arg) {
 					{
 					// Get the name of the object requested.
 					//string name = msg.directive.args;
-					LDef *obj = &myDef;
+					//LDef *obj = &myDef;
 					eak_msg retmsg;
 					retmsg.msg_type = msgPasser::SENDDATA;
 					retmsg.directive.data_type = LDEF;
-					retmsg.directive.data = static_cast<void*>(obj);
+					//retmsg.directive.data = static_cast<void*>(obj);
 					//strcpy(retmsg.directive.args, name.c_str());
 					myMsg.sendMessage(retmsg); }
 					break;
@@ -578,11 +605,11 @@ void *lineakd_core_functions::handle_messages(void *arg) {
 					{
 					// Get the name of the object requested.
 					//string name = msg.directive.args;
-					LKbd *obj = &myKbd;
+					//LKbd *obj = &myKbd;
 					eak_msg retmsg;
 					retmsg.msg_type = msgPasser::SENDDATA;
 					retmsg.directive.data_type = LKBD;
-					retmsg.directive.data = static_cast<void*>(obj);
+					//retmsg.directive.data = static_cast<void*>(obj);
 					//strcpy(retmsg.directive.args, name.c_str());
 					myMsg.sendMessage(retmsg); }
 					break;
@@ -590,11 +617,11 @@ void *lineakd_core_functions::handle_messages(void *arg) {
 					{
 					// Get the name of the object requested.
 					//string name = msg.directive.args;
-					PluginManager *obj = plugins;
+					//PluginManager *obj = plugins;
 					eak_msg retmsg;
 					retmsg.msg_type = msgPasser::SENDDATA;
 					retmsg.directive.data_type = PLUGIN_MANAGER;
-					retmsg.directive.data = static_cast<void*>(obj);
+					//retmsg.directive.data = static_cast<void*>(obj);
 					//strcpy(retmsg.directive.args, name.c_str());
 					myMsg.sendMessage(retmsg); }
 					break;
@@ -602,11 +629,11 @@ void *lineakd_core_functions::handle_messages(void *arg) {
 					{
 					// Get the name of the object requested.
 					string name = msg.directive.args;
-					LCommand *obj = &(myKbd.getObject(name)->getCommand());
+					//LCommand *obj = &(myKbd.getObject(name)->getCommand());
 					eak_msg retmsg;
 					retmsg.msg_type = msgPasser::SENDDATA;
 					retmsg.directive.data_type = LCOMMAND;
-					retmsg.directive.data = static_cast<void*>(obj);
+					//retmsg.directive.data = static_cast<void*>(obj);
 					//strcpy(retmsg.directive.args, name.c_str());
 					myMsg.sendMessage(retmsg); 
 					}
@@ -614,7 +641,7 @@ void *lineakd_core_functions::handle_messages(void *arg) {
 				default:
 					break;
 			}
-		}
+		} /*  */
 
                 msg.msg_type = 0;
                 strcpy(msg.directive.args,"");
@@ -737,7 +764,17 @@ void lineakd_core_functions::initialize_raw_keyboards(LConfig & config, LDef & d
    string coms = kb.getRawCommand("INITIALIZE");
 
    if ( (! kb.isEmpty()) && coms.length() > 0 ) {
-      send_commands(coms);
+      send_commands("send_to_keyboard", coms);
+   }
+
+}
+void lineakd_core_functions::initialize_setkeycodes(LConfig & config, LDef & def) {
+
+   LKbd & kb = def.getKeyboard(config[_CD_KEYBOARD_TYPE]);
+   string coms = kb.getRawCommand("SETKEYCODES");
+
+   if ( (! kb.isEmpty()) && coms.length() > 0 ) {
+      send_commands("setkeycodes", coms);
    }
 
 }
