@@ -228,12 +228,19 @@ int main(int argc, char *argv[])
    **************************************************************************************************/
 
   if (!X) {
-     string dis = getenv("DISPLAY");
-     X = new Xmgr(dis);
-     if ((!X->initialized()) || (X->getDisplay() == NULL)) {
-        cerr << "Could not open display: " << getenv("DISPLAY") << endl;
-  	cleanexit(false);
+     char *c_str = getenv("DISPLAY");
+     if (c_str != NULL) {
+	string dis = string(c_str);
+        X = new Xmgr(dis);
+        if ((!X->initialized()) || (X->getDisplay() == NULL)) {
+           cerr << "Could not open display: " << getenv("DISPLAY") << endl;
+  	   cleanexit(false);
+        }
      }
+     else {
+        cerr << "FATAL ERROR: $DISPLAY is not defined. Could not open a display." << endl;
+	cleanexit(false);
+     }  
   }
 
   /**************************************************************************************************
@@ -348,10 +355,12 @@ int main(int argc, char *argv[])
   exec.setDisplayCtrl(myDisplay);
 
   while(true) {
-     if (very_verbose) cout << "Waiting for next event." << endl;
+     //if (very_verbose) cout << "Waiting for next event." << endl;
+     vmsg("Waiting for next event.");
      /* wait for next event */
      XNextEvent(display, &xev);
-     if (very_verbose) cout << "Got an event." << endl;
+     //if (very_verbose) cout << "Got an event." << endl;
+     vmsg("Got an event.");
      /* Should we age the display? */
      if (myDisplay != NULL) {
         if ((xev.type != MappingNotify) && myDisplay->enabled()) {
@@ -385,11 +394,13 @@ int main(int argc, char *argv[])
 	   msg("Restarting the OSD.");
 	   myDisplay = plugins->getDisplay(myConfig);
 	   if (myDisplay != NULL) {
-	       if (very_verbose) cout << "Reiniting plugin provided On Screen Display" << endl;
+	       //if (very_verbose) cout << "Reiniting plugin provided On Screen Display" << endl;
+	       vmsg("Reiniting plugin provided On Screen Display");
 	       
 	       myDisplay->init();
 	   } else {
-	       if (very_verbose) cout << "Initializing internal display." << endl;
+	       //if (very_verbose) cout << "Initializing internal display." << endl;
+	       vmsg("Initializing internal display.");
 	       myDisplay = new displayCtrl(myConfig);
 	       myDisplay->init();
 	   }
@@ -400,9 +411,11 @@ int main(int argc, char *argv[])
 	   exec.setDisplayCtrl(myDisplay);
 //        }
      }
-     if (very_verbose) cout << "Doing something with it!" << endl;
+     //if (very_verbose) cout << "Doing something with it!" << endl;
+     vmsg("Doing something with it!");
      if (global_enable) {
-        if (very_verbose) cout << "Global Enabled" << endl;
+        //if (very_verbose) cout << "Global Enabled" << endl;
+	vmsg("Global Enabled");
         switch (xev.type)
 	{
 	   case KeyPress:
@@ -419,52 +432,44 @@ int main(int argc, char *argv[])
 		 } 
 
 	         if (obj != NULL) {
-		    msg("Got an object!");
+		    vmsg("Got an object!");
+                    msg("Looking for SYM and PRESS");
 	            if (obj->getType() == SYM && obj->getEventType() == PRESS) {
-		      cout << "xev.xkey.keycode = " << xev.xkey.keycode << endl;
-		      cout << "obj->getKeyCode() = " << obj->getKeyCode() << endl;
-		      cout << "XKeysymToKeycode (display, (KeySym)obj->getKeySym() = " << XKeysymToKeycode (display, (KeySym)obj->getKeySym()) << endl;
+		      if (verbose) {
+		         cout << "xev.xkey.keycode = " << xev.xkey.keycode << endl;
+		         cout << "obj->getKeyCode() = " << obj->getKeyCode() << endl;
+		         cout << "XKeysymToKeycode (display, (KeySym)obj->getKeySym() = " << XKeysymToKeycode (display, (KeySym)obj->getKeySym()) << endl;
+		      }
 		       if (xev.xkey.keycode == XKeysymToKeycode (display, (KeySym)obj->getKeySym())
-		           && obj->hasModifier(xev.xkey.state))
+		           && (obj->hasModifier(xev.xkey.state) || obj->isUsedAsToggle()))
 		       {
 		          execute = plugins->exec(obj, xev);
 	                  if (execute != NULL)
                              execute(obj,xev);
 			  else 
 		             exec.exec(obj,xev);
-                          /* else {
-                              if (exec.exec(obj,xev)) {
-	  	                myDisplay->show(obj->getNextToggleName());
-                             } 
-                          } */
 		       }
 	            }
 	            else {
-		        msg("Looking for CODE and PRESS");
-			
+		       msg("Looking for CODE and PRESS");
 	               if (obj->getType() == CODE && obj->getEventType() == PRESS)
 	               {
-		          if (verbose) cout << xev.xkey.keycode << " = " << obj->getKeyCode() << endl;
+		          if (very_verbose) cout << xev.xkey.keycode << " = " << obj->getKeyCode() << endl;
 			  
 			  if (obj->hasModifier(xev.xkey.state))
-			     msg("true");
+			     vmsg("true");
 			  else
-			     msg("false");
+			     vmsg("false");
 			  
 		          if ((int)xev.xkey.keycode == obj->getKeyCode()
-		              && obj->hasModifier((int)xev.xkey.state))
+		               && (obj->hasModifier((int)xev.xkey.state) || obj->isUsedAsToggle()))
 		          {
-			     msg("getting to the right place!");
+			     vmsg("getting to the right place!");
 			     execute = plugins->exec(obj,xev);
 	                     if (execute != NULL)
                                 execute(obj,xev);
 			     else 
 				exec.exec(obj,xev);
-                             /* else {
-                                if (exec.exec(obj,xev)) {
-	  	                   myDisplay->show(obj->getNextToggleName());
-                                } 
-                             } */
 		          }
 	               }
 	            }
@@ -486,34 +491,24 @@ int main(int argc, char *argv[])
 	      if (obj != NULL) { 
 	         if (obj->getType() == SYM && obj->getEventType() == RELEASE) {
 		    if (xev.xkey.keycode == XKeysymToKeycode (display, (KeySym)obj->getKeySym())
-		        && obj->hasModifier(xev.xkey.state)) {
+		        && (obj->hasModifier(xev.xkey.state) || obj->isUsedAsToggle())) {
 		       execute = plugins->exec(obj,xev);
 	               if (execute != NULL)
                           execute(obj,xev);
 		       else 
 			  exec.exec(obj,xev);
-                       /* else {
-                          if (exec.exec(obj,xev)) {
-	  	             myDisplay->show(obj->getNextToggleName());
-                          } 
-                       } */
 		    }
 	         }
 	         else {
 	            if (obj->getType() == CODE && obj->getEventType() == RELEASE) {
 		       if ((int)xev.xkey.keycode == obj->getKeyCode()
-		          && (obj->hasModifier((int)xev.xkey.state)))
+		          && (obj->hasModifier((int)xev.xkey.state) || obj->isUsedAsToggle()))
 		       {
 		          execute = plugins->exec(obj,xev);
 	                  if (execute != NULL)
                              execute(obj,xev);
 			  else
 			     exec.exec(obj,xev);
-                          /* else {
-                             if (exec.exec(obj,xev)) {
-	  	                myDisplay->show(obj->getNextToggleName());
-                             } 
-                          }*/
 		       }
 	            }
 	         }
@@ -536,19 +531,14 @@ int main(int argc, char *argv[])
 			       | Button4Mask | Button5Mask);
                 if (obj != NULL) {
 	           if (obj->getType() == BUTTON && obj->getEventType() == PRESS) {
-		      if (xev.xbutton.button == obj->getButton() && obj->hasModifier(xev.xbutton.state))
+		      if (xev.xbutton.button == obj->getButton() 
+			  && (obj->hasModifier(xev.xbutton.state) || obj->isUsedAsToggle()))
 		      {
 		       execute = plugins->exec(obj,xev);
 	               if (execute != NULL)
                           execute(obj, xev);
 		       else
 			  exec.exec(obj,xev);
-		       /*
-                       else {
-                          if (exec.exec(obj, xev)) {
-	  	             myDisplay->show(obj->getNextToggleName());
-                          }
-                       }*/
 		      }
 		}
 	     }
@@ -574,19 +564,13 @@ int main(int argc, char *argv[])
 	     if (obj->getType() == BUTTON && obj->getEventType() == RELEASE)
 		{
 		  if (xev.xbutton.button == obj->getButton()
-		      && obj->hasModifier(xev.xbutton.state))
+		      && ( obj->hasModifier(xev.xbutton.state) || obj->isUsedAsToggle()))
 		    {
 	               execute = plugins->exec(obj,xev);
 	               if (execute != NULL)
                           execute(obj,xev);
 		       else
 			  exec.exec(obj,xev);
-		       /*
-                       else {
-                          if (exec.exec(obj,xev)) {
-	  	             myDisplay->show(obj->getNextToggleName());
-                          }
-                       }*/
 		    }
 		}
 	    }
@@ -600,7 +584,8 @@ int main(int argc, char *argv[])
         
      } // End global_enable
      else {
-	     if (very_verbose) cout << "Global is not enabled." << endl;
+	     //if (very_verbose) cout << "Global is not enabled." << endl;
+	     vmsg("Global is not enabled.");
      }
 
      if (myDisplay != NULL) {
