@@ -8,13 +8,13 @@
 int main(int argc, char *argv[]) {
   int i;
 
-  if (argc == 0) {
+  if (argc <= 1) {
     printf("Usage: send_to_keyboard <control codes>\n");
     printf("    e.g. send_to_keyboard ea 17\n");
   }
   
   if (ioperm(0x60, 3, 1) == -1)
-	  perror("could not change port permissions");
+	  perror("Could not change port permissions. Please run as root.");
 
   for (i = 1; i < argc ; i++) {
       int x = strtol(argv[i], 0, 16);
